"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
// Development webpack config for server code

var webpack = require('webpack');
var nodeExternals = require('webpack-node-externals');
var _require = require('kyt-utils/paths')(),
  serverSrcPath = _require.serverSrcPath,
  serverBuildPath = _require.serverBuildPath,
  clientAssetsFile = _require.clientAssetsFile,
  loadableAssetsFile = _require.loadableAssetsFile,
  publicSrcPath = _require.publicSrcPath;
var StartServerPlugin = require('./StartServerPlugin');
var postcssLoader = require('../utils/getPostcssLoader');
var getPolyfill = require('./getPolyfill');
var nodeArgs = ['-r', 'source-map-support/register', '--max_old_space_size=4096'];
// Passthrough --inspect and --inspect-brk flags (with optional [host:port] value) to node
if (process.env.INSPECT_BRK) {
  nodeArgs.push(process.env.INSPECT_BRK);
} else if (process.env.INSPECT) {
  nodeArgs.push(process.env.INSPECT);
}
module.exports = function (options) {
  var externals = (options.externalModulesDir || ['node_modules']).map(function (modulesDir) {
    return nodeExternals({
      modulesDir: modulesDir,
      allowlist: [].concat((0, _toConsumableArray2["default"])(options.externalModulesAllowlist || []), ['webpack/hot/poll?300'])
    });
  });
  return {
    mode: 'development',
    watch: true,
    target: 'node',
    devtool: 'cheap-module-source-map',
    node: {
      __dirname: false,
      __filename: false
    },
    externals: externals,
    entry: {
      main: [require.resolve('./prettyNodeErrors'), 'webpack/hot/poll?300', getPolyfill(options.type), "".concat(serverSrcPath, "/index.js")].filter(Boolean)
    },
    output: {
      path: serverBuildPath,
      filename: '[name].js',
      chunkFilename: '[name]-[chunkhash].js',
      publicPath: options.publicPath,
      libraryTarget: 'commonjs2'
    },
    module: {
      rules: [{
        test: /\.module\.(sc|c)ss$/,
        use: [{
          loader: 'css-loader',
          options: {
            modules: {
              localIdentName: '[name]-[local]--[hash:base64:5]',
              exportOnlyLocals: true
            }
          }
        }, postcssLoader, 'sass-loader'],
        exclude: [publicSrcPath]
      }]
    },
    plugins: [
    // Prevent creating multiple chunks for the server
    new webpack.optimize.LimitChunkCountPlugin({
      maxChunks: 1
    }), new webpack.HotModuleReplacementPlugin(), new StartServerPlugin({
      name: 'main.js',
      nodeArgs: nodeArgs
    }),
    // Ignore to avoid infinite recompile bug
    new webpack.WatchIgnorePlugin([clientAssetsFile, loadableAssetsFile])]
  };
};